pub struct BidiControl {
pub start: &'static [char],
pub end: &'static [char],
}Expand description
Unicode control characters to be inserted when unicode-bidi is specified.
The unicode-bidi property is used to change the embedding of a text span within
another. This struct contains slices with the control characters that must be
inserted into the text stream at the span’s limits so that the bidi/shaping engine
will know what to do.
Fields
start: &'static [char]end: &'static [char]Implementations
Sourceimpl BidiControl
impl BidiControl
Sourcepub fn from_unicode_bidi_and_direction(
unicode_bidi: UnicodeBidi,
direction: Direction,
) -> BidiControl
pub fn from_unicode_bidi_and_direction( unicode_bidi: UnicodeBidi, direction: Direction, ) -> BidiControl
Creates a BidiControl from the properties that determine it.
See the table titled “Bidi control codes injected…” in https://www.w3.org/TR/css-writing-modes-3/#unicode-bidi